# What about Neptune?

```
WIDE SHOT: COMPUTER LAB

                        NEPTUNE

                (...Emerging from the sea,
                which has materialized in
                the corner of the computer
                lab, much to the chagrin of
                the sysadmin.)

    Thou darest call Grand-DynamoDB the first true-serverless
    graph database? [BOOMING] Audacity!


                        JORDAN

                (Without turning or looking
                away from laptop)

    Tell me the Neptune pricing model.

                        NEPTUNE

                (Rearing from throne of
                seafoam, shaking seawater
                off of his beard with rage)

    Thou simply payest for thine virtual machine!

                        JORDAN

    That sounds serverful to me.

                        NEPTUNE

    Yet thou needn't manage thine own server!

                        JORDAN

    Actually that kinda sounds like a disadvantage, if
    I'm going to the trouble of paying for CPU-hours anyway.

                        NEPTUNE

                (Red with fury, seamounts
                erupting in vicinity)

    FOOL! If thou would to pay only per-request, thou
    haveth DynamoDB, among other offerings!

                        JORDAN

    Yep, exactly. I don't use my graph database 24/7, so
    it doesn't make sense to pay for an always-on VM-equivalent.

                (NEPTUNE grows thoughtful)

    So Grand wraps DynamoDB with a graph-based API so that you
    can treat data stored in DynamoDB like any other graph.

                        NEPTUNE

    Ah, I see thine logic.

                (...Detecting a potential weakness!)

    But havest thou a standardized API?!

                        JORDAN

    Aye— I mean, yes. Grand supports interacting with a graph
    with standard NetworkX or IGraph APIs, among others.

                        NEPTUNE

                (Washing gradually back
                into the ocean, calmed...
                SUN appears over the
                SERVER RACKS)

    I am humbled. Thou mayest proceed.
```
